import sys
import os
sys.path.append(os.path.join(os.path.dirname(__file__),"../src"))

import a0_baas_sdk.redis as redis_module
# from a0_baas_sdk.redis import redis as redis_module


# 调用方法
# result = redis_module.redis.hget("pythonsdk_hset002", "f04")
# result = redis_module.redis_clients["pysdk_resource_id_03"].hget("pythonsdk_hset002", "f02")

result = redis_module.redis_clients["pysdk_resource_id_02"].get("pythonsdk_get001")
# result = redis_module.redis_clients["pysdk_resource_id_02"].set("pythonsdk_get001", "val012")

# 打印结果
print("result", result)



import requests
import json
import os


# baas-dev02.ap-southeast-1.elasticbeanstalk.com/v1/baas/data/redis/cmd/im_resource_id/hlen

def _get_redis_basic_url(host: str, resource_id: str):
  # resource_id = os.environ.get("BAAS_REDIS_RESOURCE_ID")
  # host = os.environ.get("BAAS_REDIS_SERVER_HOST")
  return f"{host}/v1/baas/data/redis/cmd/{resource_id}/"
  
class RemoteError(Exception):
  """
  远程服务器返回的错误
  """
  code = None
  http_status = None
  message = None
  data = None
  def __init__(self, code:str, http_code:str, message:str, data:dict, *args, **kwargs):
    self.code = code
    self.http_code = http_code
    self.message = message
    self.data = data
    super().__init__(*args, **kwargs)
  def __str__(self) -> str:
    return f"remote error, http_status: {self.http_code}, code: {self.code}, message: {self.message}"

_SYSTEM_ERROR_CODE = "1220002"


def _parse_redis_response(resp:requests.Response):
  if resp.status_code != 200:
    try:
      ret = resp.json()
      err = "unknown err"
      if "ResponseMetadata" in ret:
        err = ret["ResponseMetadata"]["Error"]
    except Exception:
      raise RemoteError(_SYSTEM_ERROR_CODE, resp.status_code, f"unexpected response, status code: {resp.status_code}, message: {resp.text}", None)
    raise RemoteError(err["Code"],resp.status_code, err["Message"], err["Data"])
  try:
    ret = resp.json()
    if "Result" not in ret:
      raise RemoteError(_SYSTEM_ERROR_CODE, resp.status_code, f"unexpected response, status code: {resp.status_code}, message: {resp.text}", None)
    json_val = json.loads(ret["Result"]["JSONStr"])
    return json_val
  except:
    raise RemoteError(_SYSTEM_ERROR_CODE, resp.status_code, f"unexpected response, status code: {resp.status_code}, message: {resp.text}", None)

def _redis_query(host: str, resource_id: str, redis_method: str, args):
  # 每个参数转成 string
  args = [str(arg) for arg in args]
  # 将数据转换为 JSON 格式
  json_data = json.dumps({"Args": args})
  # 设置请求头部信息
  headers = {
    "Content-Type": "application/json"
  }
  resp = requests.post(_get_redis_basic_url(host, resource_id)+redis_method, json_data, headers=headers)
  return _parse_redis_response(resp)

# redis_query(["pythonsdk_hset", "field001", "value001"])
# final_res = redis_query("hget",["pythonsdk_hset", "field001"])
# final_res = redis_query("set",["pythonsdk_set001", "v1"])
# final_res = redis_query("set",["pythonsdk_set002", "v2"])
# final_res = redis_query("get",["pythonsdk_set001"])
# final_res = redis_query("expire",["pythonsdk_set001", 10])
# final_res = redis_query("mget",["pythonsdk_set001", "pythonsdk_set002", "pythonsdk_set003"])
# final_res = redis_query("mget",[ "pythonsdk_set002"])
# final_res = redis_query("hset",[ "pythonsdk_hset002","f03","v03"])

# final_res = redis_query("hgetall",[ "pythonsdk_hset002"])


# print("final_res", final_res, final_res["f03"], final_res["f02"])



from typing import Union as _Union
# import sys
# sys.path.append(r"/cloudide/workspace/baas-sdk-python/src/")
from .remote.redis_api import _redis_query
from .remote.config import get_baas_redis_resource_id_arr as _get_baas_redis_resource_id_arr,get_baas_server_host as _get_baas_server_host


class _RedisClass:
  def __init__(self, host: str, resource_id: str):
    self.host = host
    self.resource_id = resource_id
  def hget(self, key: str, field: str) -> _Union[str, None]:
    return _redis_query(self.host, self.resource_id, "hget", [key, field])
  def get(self, key: str) -> _Union[str, None]:
    return _redis_query(self.host, self.resource_id, "get", [key])
  def set(self, key: str, value: str) -> str:
    return _redis_query(self.host, self.resource_id, "set", [key, value])

redis: _RedisClass
redis_clients: dict[str, _RedisClass] = {}

_resource_id_arr = _get_baas_redis_resource_id_arr()
_redis_host = _get_baas_server_host()

for _resource_id in _resource_id_arr:
  redis_clients[_resource_id] = _RedisClass(_redis_host, _resource_id)

if len(_resource_id_arr) > 0:
  redis = redis_clients[_resource_id_arr[0]]

# # 调用方法
# result = redis.hget("pythonsdk_hset002", "f02")

# # 打印结果
# print("result", result)